netapp_ontap.models.acl_delete API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.acl_delete`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class AclDeleteSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AclDelete object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access: str GET POST PATCH`

    Specifies whether the ACL is for DACL or SACL. It is a required field. The available values are:

    - access_allow - DACL for allow access
    - access_deny - DACL for deny access
    - audit_success - SACL for success access
    - audit_failure - SACL for failure access

    Valid choices:

    - access_allow
    - access_deny
    - audit_failure
    - audit_success
  `access_control: str GET POST PATCH`

    An Access Control Level specifies the access control of the task to be applied. Valid values are "file-directory" or "Storage-Level Access Guard (SLAG)". SLAG is used to apply the specified security descriptors with the task for the volume or qtree. Otherwise, the security descriptors are applied on files and directories at the specified path. The value SLAG is not supported on FlexGroups volumes. The default value is "file-directory" ('-' and '_' are interchangeable).

    Valid choices:

    - file_directory
    - slag
  `apply_to: ApplyTo GET POST PATCH`

    Specifies where to apply the DACL or SACL entries. You can specify more than one value by using a comma-delimited list.

  `ignore_paths: List[str] GET POST PATCH`

    Specifies that permissions on this file or directory cannot be replaced.

    Example: ["/dir1/dir2/","/parent/dir3"]

  `propagation_mode: str GET POST PATCH`

    Specifies how to propagate security settings to child subfolders and files. This setting determines how child files/folders contained within a parent folder inherit access control and audit information from the parent folder. The available values are:

    - propagate - propagate inheritable permissions to all subfolders and files
    - replace - replace existing permissions on all subfolders and files with inheritable permissions

    Valid choices:

    - propagate
    - replace